package com.terry.store.config;

import com.terry.store.config.customproperties.CustomDataSource;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.context.support.PropertySourcesPlaceholderConfigurer;
import org.springframework.jdbc.datasource.DriverManagerDataSource;

import javax.sql.DataSource;

/**
 * 数据源配置类
 *
 * @author terry
 */
@Configuration
public class DataSourceConfig {

    /**
     * 声明一个DataSource类
     *
     * @param customDataSource dataSource需要的参数
     * @return DataSource类
     */
    @Bean
    public DataSource dataSource(CustomDataSource customDataSource) {
        DriverManagerDataSource driverManagerDataSource = new DriverManagerDataSource();
        driverManagerDataSource.setDriverClassName(customDataSource.getDriverClassName());
        driverManagerDataSource.setUrl(customDataSource.getUrl());
        driverManagerDataSource.setUsername(customDataSource.getUsername());
        driverManagerDataSource.setPassword(customDataSource.getPassword());

        return driverManagerDataSource;
    }

    /**
     * 配合注解 PropertySource+Value("${xxx}")使用
     *
     * @return PropertySourcesPlaceholderConfigurer类
     */
    @Bean
    public static PropertySourcesPlaceholderConfigurer propertyPlaceholderConfigurer() {
        return new PropertySourcesPlaceholderConfigurer();
    }
}
